Learn R Programming

imguR (version 1.0.0)

get_gallery_album: Get gallery album

Description

Get album details and metadata for an album in the gallery.

Usage

get_gallery_album(album, ...)

Arguments

album
An album ID or object of class imgur_album or imgur_gallery_album.
...
Other arguments passed to HTTP request functions, for example: token (an OAuth2.0 token) or key (an API key, used by default).

Value

  • An object of class imgur_gallery_album.

Details

Get album details and metadata, for an album in the gallery. This is basically the same as get_album.

See Also

get_album get_gallery search_gallery